@@ -27,10 +27,11 @@ splash.append(progress_bar)
 
 current_progress = 0.0
 while True:
-    while current_progress <= 1.0:
-        print("Progress: {}%".format(current_progress * 100))
-        progress_bar.progress = current_progress
-        current_progress += 0.05
-        if current_progress >= 1.0:
-            current_progress = 0.0
+    # range end is exclusive so we need to use 1 bigger than max number that we want
+    for current_progress in range(0, 101, 1):
+        print("Progress: {}%".format(current_progress))
+        progress_bar.progress = current_progress / 100  # convert to decimal
         time.sleep(0.01)
+    time.sleep(0.3)
+    progress_bar.progress = 0.0
+    time.sleep(0.3)
